@@ -111,18 +111,18 @@ fn bitreverse_order<T>( arr: &mut [Complex<T>] )
 /// use num::complex::Complex;
 /// 
 /// const N:usize = 4;
-/// let mut arr  = vec![ Complex::<F<U>>::new(F::<U>::from_num(1), F::<U>::from_num(0) ); N  ];
+/// let mut arr  = vec![ Complex::<F<U>>::new(F::<U>::from_num(1f32), F::<U>::from_num(0f32) ); N  ];
 ///
-/// arr[3].re = F::<U>::from_num(0);
+/// arr[3].re = F::<U>::from_num(0f32);
 /// 
 /// fft( &mut arr );
-/// assert_eq!( arr, vec![  Complex::<F<U>>::new(F::<U>::from_num(0.75),            F::<U>::from_num(0)             ),
-///                         Complex::<F<U>>::new(F::<U>::from_num(0),               F::<U>::from_num(-0.2503761)    ),
-///                         Complex::<F<U>>::new(F::<U>::from_num(0.250376098),     F::<U>::from_num(0.0)           ),
-///                         Complex::<F<U>>::new(F::<U>::from_num(-0.000000007),    F::<U>::from_num(0.250737797)   )] );
+/// assert_eq!( arr, vec![  Complex::<F<U>>::new(F::<U>::from_num(0.75f32),            F::<U>::from_num(0f32)     ),
+///                         Complex::<F<U>>::new(F::<U>::from_num(-0.000000004f32),    F::<U>::from_num(-0.25f32) ),
+///                         Complex::<F<U>>::new(F::<U>::from_num(0.25f32),            F::<U>::from_num(0.0f32)   ),
+///                         Complex::<F<U>>::new(F::<U>::from_num(0.000000004f32),     F::<U>::from_num(0.25f32)  )] );
 /// ```
 pub fn fft<T>( array: &mut [Complex<T>] )
-    where T: MixedNum + MixedNumSigned + MixedTrigonometry
+    where T: MixedNum + MixedNumSigned + MixedTrigonometry + MixedSqrt
 {
     // Process fft.
     fft_processor(array, T::mixed_from_num(1));
@@ -159,12 +159,12 @@ pub fn fft<T>( array: &mut [Complex<T>] )
 /// 
 /// ifft( &mut arr );
 /// assert_eq!( arr, vec![  Complex::<F<U>>::new(F::<U>::from_num(0.75),         F::<U>::from_num(0.0)      ),
-///                         Complex::<F<U>>::new(F::<U>::from_num(-0.000000004), F::<U>::from_num(0.2503761)),
-///                         Complex::<F<U>>::new(F::<U>::from_num(0.250376098),  F::<U>::from_num(0.0)      ),
-///                         Complex::<F<U>>::new(F::<U>::from_num(0.00000001),   F::<U>::from_num(-0.2507378) )] );
+///                         Complex::<F<U>>::new(F::<U>::from_num(-0.000000004), F::<U>::from_num(0.25)),
+///                         Complex::<F<U>>::new(F::<U>::from_num(0.25),         F::<U>::from_num(0.0)      ),
+///                         Complex::<F<U>>::new(F::<U>::from_num(0.000000004),  F::<U>::from_num(-0.25) )] );
 /// ```
 pub fn ifft<T>( vec: &mut Vec<Complex<T>> )
-    where T: MixedNum + MixedNumSigned + MixedTrigonometry
+    where T: MixedNum + MixedNumSigned + MixedTrigonometry + MixedSqrt
 {
     // Process fft.
     fft_processor(vec, T::mixed_from_num(-1));
@@ -181,7 +181,7 @@ pub fn ifft<T>( vec: &mut Vec<Complex<T>> )
 /// * `w` - twiddle factor.
 /// 
 fn butterfly_df<T>( a: &mut Complex<T>, b: &mut Complex<T>, w:Complex<T> )
-    where T: MixedNum + MixedNumSigned + MixedTrigonometry
+    where T: MixedNum + MixedNumSigned + MixedTrigonometry + MixedSqrt
 {
     let temp_a = crate::complex::add(*a,*b);
     //  let temp_b = complex::mul_cartesian(complex::sub(*a, complex::scale_cartesian(T::from_num(2), *b)), w);
@@ -194,7 +194,7 @@ fn butterfly_df<T>( a: &mut Complex<T>, b: &mut Complex<T>, w:Complex<T> )
 /// Shared fft processor for fft and ifft.
 /// Requires bit-reversion afterwards.
 fn fft_processor<T>( array: &mut [Complex<T>], dir: T )
-    where T: MixedNum + MixedNumSigned + MixedTrigonometry
+    where T: MixedNum + MixedNumSigned + MixedTrigonometry + MixedSqrt
 {
     let n = array.len();
 
