@@ -45,10 +45,18 @@ pub mod fft;
 /// let mut x = FixedI32::<U22>::from_num(-2);
 /// let y = powi(x, 2);
 /// assert_eq!{ y.to_num::<f32>(), 4.0 };
+/// 
+/// let y = powi(x, 0);
+/// assert_eq!{ y.to_num::<f32>(), 1.0 };
 /// ``` 
 pub fn powi<T>( base:T, power:usize ) -> T
     where T: MixedNum
 {
+    if power==0
+    {
+        return T::mixed_from_num(1);
+    }
+
     let mut temp:T = base;
     for _i in 0..power-1 {
         temp = temp*base;
@@ -148,7 +156,7 @@ pub fn sin<T>( x: T ) -> T
         let delta:T = x+pi_half;
         x_ = -pi_half-delta;
     }
-    else if pi_half < x
+    else if pi_half < x_
     {
         let delta:T = x-pi_half;
         x_ = pi_half-delta;
@@ -156,8 +164,8 @@ pub fn sin<T>( x: T ) -> T
 
     // Calculate sine by using 
     let mut sinx = x_-( powi(x_,3)/<T>::from_num(6) );
-    sinx += powi(x_,5)/<T>::from_num(120);
-    sinx -= (powi(x_,7)/<T>::from_num(315)) >> 4;
+    sinx +=    powi(x_,5)/<T>::from_num(120);
+    sinx -= (  powi(x_,7)/<T>::from_num(315)) >> 4;
     sinx += (((powi(x_,9)/<T>::from_num(81))/<T>::from_num(7))/<T>::from_num(5)) >> 7;
     return sinx;
 }
